{ inputs, config, lib, ... }: {
  imports = with inputs; (self.lib.listModules ./.) ++ [
    home-manager.darwinModules.home-manager
    ../nixos/common.nix
  ];

  # Make `nix config check` happy
  environment.profiles = lib.mkForce [
    "$HOME/.nix-profile"

    # NOTE: there is no XDG_STATE_HOME in the global environment.
    # Keep this in sync with home-manager's config.xdg.stateHome value
    "$HOME/.local/state/nix/profile"

    "/run/current-system/sw"
    "/etc/profiles/per-user/$USER"
  ];

  services.nix-daemon.enable = true;

  homebrew = {
    enable = true;
    onActivation.cleanup = "zap";
    global.autoUpdate = false;
  };

  # No telemetry please, HomeBrew!
  system.activationScripts.postUserActivation.text = ''
    ${config.homebrew.brewPrefix}/brew analytics off
  '';

  system.defaults = {
    NSGlobalDomain = {
      AppleShowScrollBars = "WhenScrolling";
      NSAutomaticCapitalizationEnabled = false;
      NSAutomaticSpellingCorrectionEnabled = false;
      NSDocumentSaveNewDocumentsToCloud = false;
      "com.apple.mouse.tapBehavior" = 1;
    };
    dock = {
      autohide = true;
      orientation = "bottom";
      show-recents = false;
      showhidden = true;
      wvous-bl-corner = 11; # Launchpad
      wvous-tl-corner = 2; # Mission Control
    };
    finder = {
      AppleShowAllFiles = true;
      AppleShowAllExtensions = true;
      CreateDesktop = false;
      ShowPathbar = true;
    };
    trackpad.Clicking = true;
  };

  nix.gc = {
    automatic = true;
    options = "--delete-older-than 14d";
    interval.Day = 7;
  };

  nix.nixPath = [{ darwin-config = config.environment.darwinConfig; }];
}
