{ config, lib, pkgs, ... }:
let
  inherit (config) home xdg;

  # Enforce the same age key location on all platforms
  ageKeyFile = "${xdg.configHome}/sops/age/keys.txt";

  # Ref: https://github.com/NixOS/nixpkgs/blob/nixos-unstable/nixos/modules/services/misc/guix/default.nix
  guixUserProfiles = [
    "${xdg.configHome}/guix/current"
    "${home.homeDirectory}/.guix-home/profile"
    "${home.homeDirectory}/.guix-profile"
  ];
in
{
  imports = [
    ./options.nix
  ];

  config = lib.mkMerge [
    {
      # Follow XDG base directories specs
      xdg.enable = true;
      home.preferXdgDirectories = true;
      home.sessionVariables = {
        MIX_XDG = "true";
        GHCUP_USE_XDG_DIRS = "true";

        ANSIBLE_LOCAL_TEMP = "${xdg.cacheHome}/ansible/tmp";
        APPTAINER_CACHEDIR = "${xdg.cacheHome}/apptainer";
        LINUXKIT_CACHE = "${xdg.cacheHome}/linuxkit";
        MAGEFILE_CACHE = "${xdg.cacheHome}/magefile";
        PUPPETEER_CACHE_DIR = "${xdg.cacheHome}/puppeteer";
        TF_PLUGIN_CACHE_DIR = "${xdg.cacheHome}/terraform/plugin-cache";

        DOCKER_CONFIG = "${xdg.configHome}/docker";
        MOST_INITFILE = "${xdg.configHome}/mostrc";
        NPM_CONFIG_USERCONFIG = "${xdg.configHome}/npm/npmrc";
        WGETRC = "${xdg.configHome}/wgetrc";
        _JAVA_OPTIONS = "-Djava.util.prefs.userRoot=${xdg.configHome}/java";

        ANSIBLE_HOME = "${xdg.dataHome}/ansible";
        CARGO_HOME = "${xdg.dataHome}/cargo";
        CDKTF_HOME = "${xdg.dataHome}/terraform-cdk";
        GOPATH = "${xdg.dataHome}/go";
        GRADLE_USER_HOME = "${xdg.dataHome}/gradle";
        KREW_ROOT = "${xdg.dataHome}/krew";
        MINIKUBE_HOME = "${xdg.dataHome}";
        NPM_CONFIG_PREFIX = "${xdg.dataHome}/npm";
        OPAMROOT = "${xdg.dataHome}/opam";
        PNPM_HOME = "${xdg.dataHome}/pnpm";
        PULUMI_HOME = "${xdg.dataHome}/pulumi";
        RUSTUP_HOME = "${xdg.dataHome}/rustup";
        STACK_ROOT = "${xdg.dataHome}/stack";

        SQLITE_HISTORY = "${xdg.stateHome}/sqlite/history";
        NODE_REPL_HISTORY = "${xdg.stateHome}/node_repl_history";
      };

      sops.age.keyFile = ageKeyFile;
    }

    (lib.mkIf pkgs.stdenv.isLinux {
      xdg.userDirs = {
        enable = true;
        createDirectories = true;
      };

      xdg.mimeApps.enable = true;

      home.sessionVariables.GUIX_PROFILE = lib.concatStringsSep ":" guixUserProfiles;
      home.sessionVariables.GUIX_LOCPATH = lib.makeSearchPath "lib/locale" guixUserProfiles;
      home.sessionVariables.GUIX_EXTENSIONS_PATH = lib.makeSearchPath "share/guix/extensions" guixUserProfiles;
    })

    (lib.mkIf pkgs.stdenv.isDarwin {
      # This is the default on Linux, so only set the variable on MacOS
      home.sessionVariables.SOPS_AGE_KEY_FILE = ageKeyFile;
    })
  ];
}
