{ osConfig, config, pkgs, lib, ... }:
let
  doomConfigEntries = {
    "images" = { source = ./images; };
    "init.el" = { source = ./init.el; };
    "packages.el" = { source = ./packages.el; };
    "config.el" = {
      text = builtins.replaceStrings
        [
          "@userEmail@"
          "@userFullName@"
        ]
        [
          "${if (config.programs.git.userEmail != null) then config.programs.git.userEmail else ""}"
          "${osConfig.users.users.${config.home.username}.description}"
        ]
        (builtins.readFile ./config.el);
    };
  };
in
lib.mkMerge [
  { programs.emacs.package = with pkgs; if stdenv.isDarwin then emacs-macport else emacs29-pgtk; }

  (lib.mkIf config.programs.emacs.enable {
    # NOTE: doom's local env file should be generated manually (via `doom env`)
    # to ensure correct PATH value
    home.activation.doomSync = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      export PATH="$PATH:${lib.getBin config.programs.emacs.package}/bin:${lib.getBin pkgs.git}/bin"

      emacsDir="${config.xdg.configHome}/emacs"
      if [ ! -d "$emacsDir" ]; then
        git clone --depth 1 --single-branch https://github.com/doomemacs/doomemacs.git "$emacsDir"
        "$emacsDir"/bin/doom install --force
      fi
      "$emacsDir"/bin/doom sync -e || true
    '';

    xdg.configFile = with lib; (mapAttrs' (key: val: nameValuePair "doom/${key}" val) doomConfigEntries);
  })
]
