{ config, pkgs, ... }: {
  programs.fish.shellInit = ''
    # Set cursor shape
    set -g fish_cursor_default block
    set -g fish_cursor_insert line
    set -g fish_cursor_replace_one underscore
    set -g fish_cursor_visual block
    set -g fish_vi_force_cursor

    # Disable the default greeting message
    set -g fish_greeting

    # Nord theme
    set -g fish_color_autosuggestion 4c566a
    set -g fish_color_cancel --reverse
    set -g fish_color_command 88c0d0
    set -g fish_color_comment 4c566a --italics
    set -g fish_color_cwd 5e81ac
    set -g fish_color_cwd_root bf616a
    set -g fish_color_end 81a1c1
    set -g fish_color_error bf616a
    set -g fish_color_escape ebcb8b
    set -g fish_color_history_current eceff4 --bold
    set -g fish_color_host a3be8c
    set -g fish_color_host_remote ebcb8b
    set -g fish_color_keyword 81a1c1
    set -g fish_color_match --background=brblue
    set -g fish_color_normal normal
    set -g fish_color_operator 81a1c1
    set -g fish_color_option 8fbcbb
    set -g fish_color_param eceff4
    set -g fish_color_quote a3be8c
    set -g fish_color_redirection b48ead --bold
    set -g fish_color_search_match --bold --background=434c5e
    set -g fish_color_selection eceff4 --bold --background=434c5e
    set -g fish_color_status bf616a
    set -g fish_color_user a3be8c
    set -g fish_color_valid_path --underline
    set -g fish_pager_color_background
    set -g fish_pager_color_completion eceff4
    set -g fish_pager_color_description ebcb8b --italics
    set -g fish_pager_color_prefix normal --bold --underline
    set -g fish_pager_color_progress 3b4252 --background=d08770
    set -g fish_pager_color_secondary_background
    set -g fish_pager_color_secondary_completion
    set -g fish_pager_color_secondary_description
    set -g fish_pager_color_secondary_prefix
    set -g fish_pager_color_selected_background --background=434c5e
    set -g fish_pager_color_selected_completion
    set -g fish_pager_color_selected_description
    set -g fish_pager_color_selected_prefix
  '';

  programs.fish.functions = {
    dir_prune = {
      description = "Remove empty subdirectories recursively of a given directory";
      body = ''
        if test -d "$argv[1]"
          printf "==> Prune directory \033[1;33m$argv[1]\033[0m\n"
          for dir in (fd --full-path "$argv[1]" --type empty --type directory)
            echo "+ $dir"
            rmdir -p --ignore-fail-on-non-empty "$dir"
          end
        else
          printf "\033[1;31m$argv[1]\033[0m is not a directory\n"
          return 1
        end
      '';
    };

    # Special functions, recognized by fish
    fish_greeting.body = "not status is-login; and ${config.xdg.binHome}/bunny.sh";
    fish_user_key_bindings = {
      description = "Custom key bindings automatically executed by fish";
      body = ''
        # Use Emacs and Vim modes at the same time
        # vi-bindings take precedence when there's a conflict
        fish_default_key_bindings -M insert
        fish_vi_key_bindings --no-erase insert

        # Make <Alt-j> and <Alt-k> behaves like <Alt+↓> and <Alt+↑> (shorter hand distant)
        bind -M insert \ej history-token-search-forward
        bind -M insert \ek history-token-search-backward
      '';
    };

    # Dummy functions, used solely to register abbrs
    __multicd = ''echo cd (string repeat -n (math (string length -- $argv[1]) - 1) ../)'';
    __last_history_item = ''echo $history[1]'';
  };

  programs.fish.shellAbbrs = {
    # string values are used as shellAliases for other shells
    ad = "ansible-doc";
    ap = "ansible-playbook";
    e = "emacs -nw";
    em = "emacsclient -c -a emacs";
    k = "kubectl";
    kn = "kubens";
    kx = "kubectx";
    p = "pulumi";
    t = "tofu";
    v = "nvim";
    vv = ''fzf --prompt "Edit files: " --preview "${config.xdg.binHome}/preview.sh {} \$FZF_PREVIEW_COLUMNS \$FZF_PREVIEW_LINES 2>/dev/null" --bind "enter:become(nvim {+})"'';

    # special abbr, available for fish-shell only
    "!!" = {
      position = "anywhere";
      function = "__last_history_item";
    };
    dotdot = {
      regex = ''^\.\.+$'';
      function = "__multicd";
    };
  };

  # NOTE: sha256 can be retrieved manually instead of letting the build fail for the 1st time.
  # Run: nix-prefetch-github --rev <rev> <owner> <repo>
  # Ref: https://github.com/NixOS/nixpkgs/issues/191128
  programs.fish.plugins = [
    {
      name = "autopair";
      src = pkgs.fetchFromGitHub {
        owner = "jorgebucaran";
        repo = "autopair.fish";
        rev = "4d1752ff5b39819ab58d7337c69220342e9de0e2";
        hash = "sha256-qt3t1iKRRNuiLWiVoiAYOu+9E7jsyECyIqZJ/oRIT1A=";
      };
    }
  ];
}
