{ osConfig, config, lib, ... }: {
  programs.git = {
    # Placeholder, since other modules use it
    signing.key = lib.mkDefault null;

    userName = "${osConfig.users.users.${config.home.username}.description}";
    aliases = {
      l = "log --all --graph --pretty=format:'%C(yellow)%h%Creset %C(bold)<%an>%Creset -%C(bold)%C(green)%d%Creset %C(blue)%s%Creset (%cr)'";
      br = "branch --sort=-committerdate --format='%(HEAD) %(color:yellow)%(refname:short)%(color:reset) %(color:bold)<%(authorname)>%(color:reset) - %(color:blue)%(contents:subject)%(color:reset) (%(committerdate:relative))'";
      s = "status -sbu";
      sbu = "submodule update --remote --rebase";
      redo = "reset HEAD~1";
      unstage = "reset HEAD";
      wdiff = "diff --word-dif";
      compare = "!git log $1...$2 --format='%C(bold)%C(green)%m%Creset %C(yellow)%h%Creset %C(bold)<%an>%Creset - %C(blue)%s%Creset' --left-right";
    };
    lfs = {
      enable = true;
      skipSmudge = true;
    };
    signing.signByDefault = true;
    extraConfig = {
      core = {
        whitespace = "trailing-space";
        autocrlf = "input";
      };
      init.defaultBranch = "main";
      commit.verbose = true;
      rebase.autoSquash = true;
      pull.rebase = true;
      push.followTags = true;
      fetch.prune = true;
      submodule.recurse = true;
      help.autoCorrect = "prompt";
      color.ui = true;
      diff.wsErrorHighlight = "all";
      format.useAutoBase = true;

      # External stuff
      sendemail.annotate = true;
    };
  };
}
