{ config, lib, ... }: {
  programs.gpg = {
    homedir = "${config.xdg.dataHome}/gnupg";
    settings = {
      default-key = lib.mkIf (config.programs.git.signing.key != null) config.programs.git.signing.key;
      keyserver = "hkps://keys.gnupg.net";
      auto-key-locate = "keyserver";
      keyserver-options = "no-honor-keyserver-url";
      cert-digest-algo = "SHA512";
      s2k-cipher-algo = "AES256";
      s2k-digest-algo = "SHA512";
      personal-cipher-preferences = "AES256 AES192 AES CAMELLIA256 TWOFISH";
      personal-digest-preferences = "SHA512 SHA384 SHA256";
      personal-compress-preferences = "ZLIB BZIP2 ZIP";
      default-preference-list = "SHA512 SHA384 SHA256 AES256 AES192 AES CAMELLIA256 TWOFISH ZLIB BZIP2 ZIP";
      default-new-key-algo = "ed25519/cert,sign+cv25519/encr";

      display-charset = "utf-8";
      no-comments = true;
      no-greeting = true;
      no-emit-version = true;
      ignore-time-conflict = true;
      no-symkey-cache = true;
      with-fingerprint = true;
      keyid-format = "0xlong";
      default-recipient-self = true;
      require-cross-certification = true;
    };
  };
}
