{ config, lib, pkgs, ... }:
let
  gitBin = "${lib.getBin pkgs.git}/bin/git";
in
{
  programs.neovim = {
    withPython3 = true;
    withNodeJs = true;

    extraPackages = with pkgs; [
      # to compile tree-sitter grammars
      gcc
      tree-sitter

      # LSP/DAP servers
      # NOTE: only specify programs run as a LSP server here (general purpose CLIs, .e.g taplo, clang-tools will be added to users' environment packages)
      beancount-language-server
      delve
      dhall-lsp-server
      gopls
      jsonnet-language-server
      ltex-ls
      lua-language-server
      marksman
      metals
      nil
      nls
      # terraform-ls
      texlab
      typst-lsp
      zls
    ];
  };

  # Clone my personal Neovim config
  home.activation.fetchNeovimConfig = lib.mkIf config.programs.neovim.enable ''
    nvim_confdir="${config.xdg.configHome}/nvim"
    if [ -d "$nvim_confdir" ]; then
      cd "$nvim_confdir"
      ${gitBin} pull --rebase origin main || true
    else
      ${gitBin} clone --depth=1 --branch=main https://gitlab.com/folliehiyuki/nvim.git "$nvim_confdir"
    fi
  '';
}
