{ config, lib, ... }:
with lib;
{
  # Avoid home.sessionPath as it is loaded too early, and also modifies PATH directly
  options.home.shellPaths = mkOption {
    type = with types; listOf str;
    default = [ ];
    example = [
      "/home/follie/.local/bin"
      "\${xdg.configHome}/emacs/bin"
      ".git/safe/../../bin"
    ];
    description = ''
      Extra directories to add to {env}`PATH` via
      each shell's specific init file.
    '';
  };

  config = {
    programs.zsh.loginExtra = ''
      ${lib.concatLines (builtins.map (x: "[ -d ${escapeShellArg x} ] && path+=(${escapeShellArg x})") config.home.shellPaths) }
      typeset -U PATH path
      export PATH
    '';

    programs.fish.loginShellInit = ''
      for path in ${escapeShellArgs config.home.shellPaths}
        test -d $path; and set -ga fish_user_paths $path
      end
    '';
  };
}
