# NOTE: fish, zsh and bash inherit home.{shellAliases,sessionVariables} options properly.
# nushell and ion don't.
{ osConfig, config, pkgs, ... }:
let
  inherit (config) home xdg;
in
{
  home.shellAliases = {
    cp = "cp -vir";
    mv = "mv -vi";
    rm = "rm -vr";
    mkdir = "mkdir -vp";
  };

  home.sessionVariables = {
    # Common env
    PAGER = "less";
    MANPAGER = "less -R --use-color -Dd+b -Du+g -DS+kc";
    LESS = "-R -i -M --incsearch";
    LESSOPEN = "|bat %s";
    LESSHISTFILE = "-";
    BROWSER = if pkgs.stdenv.isDarwin then "open" else "xdg-open";

    # Stupid telemetry and update check
    ATLAS_NO_UPDATE_NOTIFIER = "true";
    AZURE_CORE_COLLECT_TELEMETRY = "false";
    CHECKPOINT_DISABLE = "true";
    CLOUDSDK_COMPONENT_MANAGER_DISABLE_UPDATE_CHECK = "true";
    CLOUDSDK_CORE_DISABLE_USAGE_REPORTING = "true";
    DCTL_NO_VERSION_CHECK = "true";
    DENO_NO_UPDATE_CHECK = "true";
    DISABLE_CRASH_REPORT = "false";
    DISABLE_VERSION_CHECK = "true";
    DOTNET_CLI_TELEMETRY_OPTOUT = "true";
    DOTNET_SKIP_FIRST_TIME_EXPERIENCE = "true";
    DO_NOT_TRACK = 1;
    HELMFILE_UPGRADE_NOTICE_DISABLED = "true";
    KOPIA_CHECK_FOR_UPDATES = "false";
    KUBESHARK_DISABLE_VERSION_CHECK = "true";
    OPA_TELEMETRY_SERVICE_URL = "http://0.0.0.0";
    PULUMI_AUTOMATION_API_SKIP_VERSION_CHECK = "true";
    PULUMI_SKIP_UPDATE_CHECK = "true";
    QSV_NO_UPDATE = "true";
    SAM_CLI_TELEMETRY = 0;
    TABBY_DISABLE_USAGE_COLLECTION = 1;
    TURBO_TELEMETRY_DISABLED = 1;

    # cargo
    CARGO_REGISTRIES_CRATES_IO_PROTOCOL = "sparse";
    OPENSSL_NO_VENDOR = 1;
    # go
    GOPROXY = "direct";
    GOSUMDB = "off";
    GOTOOLCHAIN = "local";
    # helmfile
    HELMFILE_DISABLE_INSECURE_FEATURES = "true";
    HELMFILE_SKIP_INSECURE_TEMPLATE_FUNCTIONS = "true";
    # kopia
    KOPIA_PERSIST_CREDENTIALS_ON_CONNECT = "false";
    # qsv
    QSV_PROGRESSBAR = "true";
    # mage
    MAGEFILE_ENABLE_COLOR = "true";
    # skip chromium/electron download
    PUPPETEER_EXECUTABLE_PATH =
      if pkgs.stdenv.isDarwin
      then "${osConfig.homebrew.brewPrefix}/chromium"
      else "${config.programs.chromium.package}/bin/chromium-browser";
    PUPPETEER_SKIP_DOWNLOAD = "true";
    ELECTRON_SKIP_BINARY_DOWNLOAD = 1;
  };

  home.shellPaths =
    let
      vars = home.sessionVariables;
    in
    [
      "${xdg.binHome}"
      "${vars.CARGO_HOME}/bin"
      "${vars.GOPATH}/bin"
      "${vars.NPM_CONFIG_PREFIX}/bin"
      "${vars.PNPM_HOME}/bin"
    ];
}
