{ osConfig, config, lib, pkgs, ... }:
let
  brewSetup = "${osConfig.homebrew.brewPrefix}/brew shellenv";
in
{
  disabledModules = [ "targets/darwin/linkapps.nix" ];

  config = lib.mkIf pkgs.stdenv.isDarwin {
    # Symlinks don't work with finder + spotlight
    # Ref: https://github.com/nix-community/home-manager/issues/1341
    home.activation.copyApplications =
      let
        apps = pkgs.buildEnv {
          name = "home-manager-applications";
          paths = config.home.packages ++ osConfig.users.users.${config.home.username}.packages;
          pathsToLink = "/Applications";
        };
      in
      lib.hm.dag.entryAfter [ "writeBoundary" ] ''
        baseDir="$HOME/Applications/Home Manager Apps"
        if [ -d "$baseDir" ]; then
          rm -rf "$baseDir"
        fi
        mkdir -p "$baseDir"
        for appFile in ${apps}/Applications/*.app; do
          target="$baseDir/$(basename "$appFile")"
          $DRY_RUN_CMD cp ''${VERBOSE_ARG:+-v} -fHRL "$appFile" "$baseDir"
          $DRY_RUN_CMD chmod ''${VERBOSE_ARG:+-v} -R +w "$target"
        done
      '';

    home.sessionVariables.HOMEBREW_NO_ANALYTICS = 1;

    programs.zsh.initExtra = "eval $(${brewSetup})";
    programs.fish.shellInitLast = "${brewSetup} | source";

    targets.darwin = {
      search = "DuckDuckGo";
      currentHostDefaults."com.apple.controlcenter".BatteryShowPercentage = true;
      defaults."com.apple.desktopservices" = {
        DSDontWriteNetworkStores = true;
        DSDontWriteUSBStores = true;
      };
    };
  };
}
