{ config, lib, pkgs, ... }:
let
  managedNormalUsers = [ "follie" "gema" ];
in
lib.mkMerge [
  # Set users' passwords
  (lib.foldr (a: b: lib.recursiveUpdate a b) { }
    (builtins.map
      (name:
        let
          secretPath = "${name}-hashedPassword";
        in
        {
          sops.secrets.${secretPath}.neededForUsers = true;
          users.users.${name}.hashedPasswordFile = config.sops.secrets.${secretPath}.path;
        })
      ([ "root" ] ++ managedNormalUsers)))

  {
    # Enable corresponding shells for each user
    programs.fish.enable = true;
    programs.zsh.enable = true;

    users.mutableUsers = false;
    users.users = {
      follie = {
        isNormalUser = true;
        description = "Hoang Nguyen";
        extraGroups = [ "wheel" "networkmanager" "libvirtd" ];
        shell = pkgs.fish;

        # Ref: https://rootlesscontaine.rs/getting-started/common/subuid/
        autoSubUidGidRange = true;
      };

      gema = {
        isNormalUser = true;
        description = "Gamer";
        extraGroups = [ "networkmanager" ];
        shell = pkgs.zsh;

        # This user doesn't run rootless containers
        autoSubUidGidRange = false;
      };
    };

    # Stuff available for all users
    environment.systemPackages = with pkgs; [
      clinfo
      glxinfo
      (hunspellWithDicts (with hunspellDicts; [ en_US-large ru_RU ]))
      # kdePackages.audiotube # FIXME: currently broken (probably due to it not being compatible with python3-ytmusicapi v1.6.0 yet)
      kdePackages.plasmatube
      libreoffice-qt
      obs-studio
      pciutils
      vulkan-tools
    ];

    home-manager.users = lib.genAttrs managedNormalUsers (name: import ./${name}.nix);

    # The users need to be able to connect to the Nix daemon for their home-manager systemd services to work
    nix.settings.allowed-users = managedNormalUsers;
  }
]
