{ config, pkgs, ... }: {
  home.packages = with pkgs; [
    age
    ansible
    ansible-lint
    apptainer
    asciidoctor-with-extensions
    bazel-buildtools
    biome
    buf
    cargo
    chafa
    cosign
    coursier
    croc
    cue
    deno
    docker-machine-kvm2 # used by minikube's qemu2 backend
    elixir
    fd
    ffmpegthumbnailer
    git-filter-repo
    git-privacy
    gleam
    glow
    gnumake
    go
    go-jsonnet
    go-task
    gojq
    golangci-lint
    haskellPackages.pandoc-cli
    hexyl
    httm
    hyperfine
    imagemagick
    kdePackages.akregator
    kdePackages.konversation
    kdePackages.neochat
    kdePackages.tokodon
    keepassxc
    kubectl
    kubectx
    kubernetes-helm
    ldns # provide drill binary
    libarchive
    libclang
    linuxkit
    lua54Packages.lua
    mbuffer
    mill
    minikube
    ncdu
    nixpkgs-fmt
    nmap
    nodejs-slim
    nvme-cli
    okteta
    onefetch
    open-policy-agent
    podman
    procs
    psmisc
    pulumi
    pulumiPackages.pulumi-language-go
    pulumiPackages.pulumi-language-nodejs
    purescript
    python3
    reuse
    rsync
    s5cmd
    sbt
    scala_3
    scalafmt
    selene
    shellcheck
    smartmontools
    sops
    stern
    streamlink
    stylua
    tanka
    taplo
    templ
    testdisk-qt
    tokei
    tor-browser
    tree-sitter
    trivy
    typst
    typstfmt
    valgrind
    virt-manager
    wl-clipboard-rs
    yq-go
    zig
  ];

  # Pretend that `jq` is available
  home.file."${config.xdg.binHome}/jq".source = "${pkgs.gojq}/bin/gojq";

  programs = {
    alacritty = {
      enable = true;
      settings.font.size = 13.5;
    };
    bat.enable = true;
    chromium.enable = true;
    direnv.enable = true;
    emacs.enable = true;
    fish.enable = true;
    foot.enable = true;
    fzf.enable = true;
    gallery-dl.enable = true;
    gh.enable = true;
    ghq.enable = true;
    git = {
      enable = true;
      package = pkgs.gitFull;
      signing.key = "B0567C20730E9B11";
      userEmail = "folliekazetani@protonmail.com";
      extraConfig.privacy = {
        ignoreTimezone = true;
        pattern = "hms";
      };
    };
    git-forgit.enable = true;
    gpg.enable = true;
    k9s.enable = true;
    lsd.enable = true;
    luarocks = {
      enable = true;
      settings =
        let
          inherit (config) xdg;
        in
        {
          home_tree = "${xdg.dataHome}/luarocks";
          homeconfdir = "${xdg.configHome}/luarocks";
          local_by_default = true;
          rocks_trees = [
            { name = "user"; root = "${xdg.dataHome}/luarocks"; }
          ];
        };
    };
    neovim = {
      enable = true;
      defaultEditor = true;
    };
    opam.enable = true;
    pnpm.enable = true;
    ripgrep.enable = true;
    starship.enable = true;
    translate-shell.enable = true;
    vivid.enable = true;
    zellij.enable = true;
    zoxide.enable = true;
  };

  services.gpg-agent.pinentryPackage = pkgs.pinentry-qt;
}
