{ pkgs, ... }:
let
  username = "hoang.nguyenhuy";
in
{
  environment.pathsToLink = [
    "/share/qemu" # expose edk2-aarch64-code.fd in a stable path for podman/minikube
  ];

  environment.shells = [ pkgs.zsh ];

  programs = {
    amethyst.enable = true;
    zsh.enable = true;
  };

  services.socket_vmnet.enable = true;

  fonts.fonts = with pkgs; [
    sarasa-gothic
    iosevka-bin
    (iosevka-bin.override { variant = "Aile"; })
    (iosevka-bin.override { variant = "Etoile"; })
    (nerdfonts.override { fonts = [ "IosevkaTerm" ]; })
  ];

  homebrew.casks = [
    "aws-vpn-client"
    "displaylink"
    "openlens"
  ];

  # NOTE: re-apply this configuration whenever MacOS does a system upgrade
  security.pam.enableSudoTouchIdAuth = true;

  # Ref: https://github.com/LnL7/nix-darwin/issues/328
  system.activationScripts.postActivation.text = ''
    chpass -s ${pkgs.zsh}/bin/zsh ${username}
  '';

  users.users.${username} = {
    home = "/Users/${username}";
    description = "Hoang Nguyen Huy";
    isHidden = false;

    # Ref: https://github.com/LnL7/nix-darwin/issues/122
    # so no fish-shell then
    shell = pkgs.zsh;

    packages = with pkgs; [
      age
      aws-sso-cli
      awscli2
      azure-cli
      cargo
      chafa
      croc
      cue
      dbeaver
      docker-buildx
      docker-client
      docker-compose
      fd
      gnumake
      go
      go-tools
      gojq
      golangci-lint
      google-cloud-sdk
      hoppscotch
      (hunspellWithDicts (with hunspellDicts; [ en_US-large ]))
      iterm2
      keepassxc
      kubectl
      kubectx
      kubernetes-helm
      lima
      maccy
      minikube
      nodejs-slim
      (packer.overrideAttrs { doCheck = false; })
      opentofu
      pulumi-bin
      qemu_kvm
      s5cmd
      shellcheck
      sops
      ssm-session-manager-plugin
      stern
      (terraform.overrideAttrs { doCheck = false; })
      (vault.overrideAttrs { doCheck = false; })
      youtube-music
    ];
  };

  home-manager.users.${username} = import ./user.nix;

  nix.settings.trusted-users = [ username ];

  nixpkgs.hostPlatform = "aarch64-darwin";
}
