{ config, pkgs, ... }: {
  programs = {
    bat.enable = true;
    direnv.enable = true;
    emacs.enable = true;
    fzf.enable = true;
    gallery-dl = {
      enable = true;
      settings.base-directory = "${config.home.homeDirectory}/Downloads/gallery-dl";
    };
    gh.enable = true;
    ghq.enable = true;
    git = {
      enable = true;
      signing.key = "4DDE6212A7FDB0E1";
      userEmail = "hoang.nguyenhuy@optimizely.com";
    };
    gpg.enable = true;
    k9s.enable = true;
    lsd.enable = true;
    neovim = {
      enable = true;
      defaultEditor = true;
    };
    opam.enable = true;
    pnpm.enable = true;
    ripgrep.enable = true;
    translate-shell.enable = true;
    starship.enable = true;
    vivid.enable = true;
    vscode = {
      enable = true;

      # These extensions come from `nix-vscode-extensions` overlay (set via nixpkgs.overlays)
      extensions = with pkgs; [
        open-vsx.arcticicestudio.nord-visual-studio-code
        open-vsx.asciidoctor.asciidoctor-vscode
        open-vsx.brody715.vscode-cuelang
        open-vsx.coenraads.bracket-pair-colorizer-2
        open-vsx.editorconfig.editorconfig
        open-vsx.mhutchie.git-graph
        open-vsx.vscode-org-mode.org-mode
        open-vsx.golang.go
        open-vsx.grafana.vscode-jsonnet
        open-vsx.hashicorp.terraform
        open-vsx.jnoortheen.nix-ide
        open-vsx.mads-hartmann.bash-ide-vscode
        open-vsx.ms-kubernetes-tools.vscode-kubernetes-tools
        open-vsx.pkief.material-icon-theme
        open-vsx.eamodio.gitlens
        open-vsx.redhat.vscode-yaml # Kubernetes extension depends on this
        # open-vsx.tabbyml.vscode-tabby
        vscode-marketplace.tsandall.opa
        open-vsx.vscodevim.vim
      ];

      userSettings = {
        "workbench.colorTheme" = "Nord";
        "workbench.iconTheme" = "material-icon-theme";
        "asciidoc.preview.fontSize" = 16;
        "markdown.preview.fontSize" = 16;
        "terminal.integrated.fontFamily" = "'IosevkaTerm Nerd Font', Iosevka, monospace";
        "terminal.integrated.fontSize" = 16;
        "chat.editor.fontSize" = 16;
        "debug.console.fontSize" = 16;
        "scm.inputFontSize" = 16;
        "editor.fontSize" = 16;
        "editor.fontFamily" = "Iosevka, Menlo, Monaco, 'Courier New', monospace";
        "telemetry.telemetryLevel" = "off";
        "terraform.codelens.referenceCount" = true;
        "nix.enableLanguageServer" = true;
        "nix.serverPath" = "nil";
        "bracket-pair-colorizer-2.showHorizontalScopeLine" = false;
        "bracket-pair-colorizer-2.forceUniqueOpeningColor" = true;
        "bracket-pair-colorizer-2.colors" = [ "#d08770" "#ebcb8b" "#a3be8c" "#88c0d0" "#81a1c1" "#b48ead" ];
        "bracket-pair-colorizer-2.unmatchedScopeColor" = "#bf616a";
        "redhat.telemetry.enabled" = false;
        "yaml.format.printWidth" = 120;
        "jsonnet.languageServer.enableAutoUpdate" = false;

        # To start tabby local API service: `tabby serve --port 10069 --device metal --model TabbyML/StarCoder-3B`
        "tabby.api.endpoint" = "http://127.0.0.1:10069";
        "tabby.inlineCompletion.triggerMode" = "manual";
        "tabby.usage.anonymousUsageTracking" = true; # this settings actually disables telemetry (pretty weird naming)
      };
    };
    zellij.enable = true;
    zoxide.enable = true;
    zsh.enable = true;
  };
}
