{ inputs, lib, ... }: {
  imports = with inputs; (self.lib.listModules ./.) ++ [
    disko.nixosModules.disko
    home-manager.nixosModules.home-manager
    impermanence.nixosModules.impermanence
    sops-nix.nixosModules.sops
  ];

  documentation.man.generateCaches = true;

  # Set a more restricted umask globally. See pam_umask(8).
  # NOTE: login.defs file is used here since it has the lowest priority considered by pam_umask
  security.loginDefs.settings.UMASK = "027";
  security.pam.services =
    let
      text = ''
        session optional pam_umask.so
      '';
    in
    {
      login.text = lib.mkDefault text;
      systemd-user.text = lib.mkDefault text;
    };

  # cgroups isn't available on MacOS
  nix.settings = {
    trusted-users = [ "@wheel" ];
    use-cgroups = true;
    experimental-features = [ "cgroups" ];
  };

  nix.gc = {
    automatic = true;
    options = "--delete-older-than 14d";
    dates = "weekly";
    persistent = true;
  };
}
