{ config, lib, ... }:
let
  cfg = config.services.guix;
in
lib.mkIf cfg.enable {
  services.guix = {
    extraArgs = [
      "--cores=0"
      "--max-jobs=${builtins.toString cfg.nrBuildUsers}"
    ];

    # follow nix settings
    stateDir = "/gnu/var";
    gc = {
      enable = true;
      extraArgs = [
        "--optimize"
        "--vacuum-database"
        "--delete-generations=14d"
      ];
      dates = lib.mkDefault config.nix.gc.dates;
    };
  };

  # Allow the usage of `guix system vm`
  # Ref: https://guix.gnu.org/manual/en/html_node/Build-Environment-Setup.html
  users.users = lib.genAttrs
    (builtins.genList
      (x: "guixbuilder${builtins.toString x}")
      cfg.nrBuildUsers)
    (_: { extraGroups = [ "kvm" ]; });
}
